//-----------------------------------------------------------------------
//	File:		$RCSfile: Lab3OutputDecode.v,v $
//	Version:	$Revision: 1.4 $
//	Desc:		7 Segment LED Decoder for Lab3
//	Author:		Greg Gibeling
//	Copyright:	Copyright 2003-2004 UC Berkeley
//	This copyright header must appear in all derivative works.
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Section:	Change Log
//-----------------------------------------------------------------------
//	$Log: Lab3OutputDecode.v,v $
//	Revision 1.4  2004/07/08 21:54:13  Administrator
//	Fixed bug (Swapped Prog1/Prog2 output)
//	
//	Revision 1.3  2004/07/08 21:53:12  Administrator
//	Added combo reprogramming
//	Implemented and Tested
//	
//	Revision 1.2  2004/07/08 18:40:54  Administrator
//	Fixed typos
//	
//	Revision 1.1  2004/07/08 16:07:13  Administrator
//	Initial Import
//	
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Module:		Lab3OutputDecode
//	Desc:		This module will take the outputs from the lock
//			FSM and decode them to 5x 7Segment displays to
//			produce a human readable status message.
//-----------------------------------------------------------------------
module Lab3OutputDecode(Open, Error, Prog1, Prog2, SEG1, SEG2, SEG3, SEG4, SEG5);
	//---------------------------------------------------------------
	//	Combination Lock Outputs
	//---------------------------------------------------------------
	input			Open, Error;
	input			Prog1, Prog2;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	7 Segment Driver Lines
	//---------------------------------------------------------------
	output	[7:1]		SEG1, SEG2, SEG3, SEG4, SEG5;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Regs
	//---------------------------------------------------------------
	reg	[7:1]		SEG1, SEG2, SEG3, SEG4, SEG5;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	A Complicated Decoder
	//---------------------------------------------------------------
	always @ (Open or Error or Prog1 or Prog2) begin
		case ({Open, Error, Prog1, Prog2})
			4'b0000: begin
				SEG1 = 7'b0000000;	// Nothing, All Off
				SEG2 = 7'b0000000;
				SEG3 = 7'b0000000;
				SEG4 = 7'b0000000;
				SEG5 = 7'b0000000;
			end
			4'b0001: begin
				SEG1 = 7'b1110011;	// Prog2
				SEG2 = 7'b1010000;
				SEG3 = 7'b1011100;
				SEG4 = 7'b1101111;
				SEG5 = 7'b1011011;
			end
			4'b0010: begin
				SEG1 = 7'b1110011;	// Prog1
				SEG2 = 7'b1010000;
				SEG3 = 7'b1011100;
				SEG4 = 7'b1101111;
				SEG5 = 7'b0000110;
			end
			4'b0100: begin
				SEG1 = 7'b1111001;	// Error
				SEG2 = 7'b1010000;
				SEG3 = 7'b1010000;
				SEG4 = 7'b1011100;
				SEG5 = 7'b1010000;
			end
			4'b1000: begin
				SEG1 = 7'b0000000;	// _OPEN
				SEG2 = 7'b0111111;
				SEG3 = 7'b1110011;
				SEG4 = 7'b1111001;
				SEG5 = 7'b0110111;
			end
			default: begin
				SEG1 = 7'b1110001;	// FA7AL
				SEG2 = 7'b1110111;
				SEG3 = 7'b0000111;
				SEG4 = 7'b1110111;
				SEG5 = 7'b0111000;
			end
		endcase
	end
	//---------------------------------------------------------------
endmodule
//-----------------------------------------------------------------------